pub enum ProtoConversionError {
MissingMapping,
GammaMismatch {
expected: f64,
actual: f64,
},
NonZeroIndexOffset {
actual: f64,
},
UnsupportedInterpolation {
actual: i32,
},
NegativeBinCount {
index: i32,
count: f64,
},
NonIntegerBinCount {
index: i32,
count: f64,
},
NegativeZeroCount {
count: f64,
},
NonIntegerZeroCount {
count: f64,
},
}Expand description
Errors that can occur during protobuf conversion.
Variants
MissingMapping
The protobuf message is missing the required mapping field.
GammaMismatch
The gamma value in the protobuf doesn’t match the expected gamma.
NonZeroIndexOffset
The index offset is non-zero, which isn’t supported by LogarithmicMapping.
UnsupportedInterpolation
The interpolation mode isn’t supported.
NegativeBinCount
A bin count value is negative, which is invalid.
NonIntegerBinCount
A bin count value isn’t a valid integer.
NegativeZeroCount
The zero count is negative.
NonIntegerZeroCount
The zero count isn’t a valid integer.